from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiProfileTimeInformation")


@attr.s(auto_attribs=True)
class ApiProfileTimeInformation:
    """Time information used in profiling"""

    time: Union[Unset, None, str] = UNSET
    milli_seconds: Union[Unset, int] = UNSET
    step: Union[Unset, None, str] = UNSET
    micro_service: Union[Unset, None, str] = UNSET
    sorting_order: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        time = self.time
        milli_seconds = self.milli_seconds
        step = self.step
        micro_service = self.micro_service
        sorting_order = self.sorting_order

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if time is not UNSET:
            field_dict["Time"] = time
        if milli_seconds is not UNSET:
            field_dict["milliSeconds"] = milli_seconds
        if step is not UNSET:
            field_dict["step"] = step
        if micro_service is not UNSET:
            field_dict["microService"] = micro_service
        if sorting_order is not UNSET:
            field_dict["sortingOrder"] = sorting_order

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        time = d.pop("Time", UNSET)

        milli_seconds = d.pop("milliSeconds", UNSET)

        step = d.pop("step", UNSET)

        micro_service = d.pop("microService", UNSET)

        sorting_order = d.pop("sortingOrder", UNSET)

        api_profile_time_information = cls(
            time=time,
            milli_seconds=milli_seconds,
            step=step,
            micro_service=micro_service,
            sorting_order=sorting_order,
        )

        return api_profile_time_information



from enum import Enum


class FlashCalculationType(int, Enum):
    PT = 0
    """Fixed Temperature/Pressure"""
    PH = 1
    """Fixed Temperature/Enthalpy"""
    PS = 2
    """Fixed Temperature/Entropy"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputCalculationResultPhasePolymerMoment")


@attr.s(auto_attribs=True)
class ApiOutputCalculationResultPhasePolymerMoment:
    """Moment for a polymer in a phase"""

    polymer_name: Union[Unset, None, str] = UNSET
    mn: Union[Unset, float] = UNSET
    mw: Union[Unset, float] = UNSET
    mz: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        polymer_name = self.polymer_name
        mn = self.mn
        mw = self.mw
        mz = self.mz

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if polymer_name is not UNSET:
            field_dict["polymerName"] = polymer_name
        if mn is not UNSET:
            field_dict["mn"] = mn
        if mw is not UNSET:
            field_dict["mw"] = mw
        if mz is not UNSET:
            field_dict["mz"] = mz

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        polymer_name = d.pop("polymerName", UNSET)

        mn = d.pop("mn", UNSET)

        mw = d.pop("mw", UNSET)

        mz = d.pop("mz", UNSET)

        api_output_calculation_result_phase_polymer_moment = cls(
            polymer_name=polymer_name,
            mn=mn,
            mw=mw,
            mz=mz,
        )

        return api_output_calculation_result_phase_polymer_moment



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_output_calculation_result_phase import ApiOutputCalculationResultPhase
from ..models.api_value_pressure import ApiValuePressure
from ..models.api_value_temperature import ApiValueTemperature
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputCalculationResultPoint")


@attr.s(auto_attribs=True)
class ApiOutputCalculationResultPoint:
    """Result for a point"""

    temperature: Union[Unset, ApiValueTemperature] = UNSET
    pressure: Union[Unset, ApiValuePressure] = UNSET
    phases: Union[Unset, None, List[ApiOutputCalculationResultPhase]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        temperature: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.temperature, Unset):
            temperature = self.temperature.to_dict()

        pressure: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pressure, Unset):
            pressure = self.pressure.to_dict()

        phases: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.phases, Unset):
            if self.phases is None:
                phases = None
            else:
                phases = []
                for phases_item_data in self.phases:
                    phases_item = phases_item_data.to_dict()

                    phases.append(phases_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if pressure is not UNSET:
            field_dict["pressure"] = pressure
        if phases is not UNSET:
            field_dict["phases"] = phases

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _temperature = d.pop("temperature", UNSET)
        temperature: Union[Unset, ApiValueTemperature]
        if isinstance(_temperature, Unset):
            temperature = UNSET
        else:
            temperature = ApiValueTemperature.from_dict(_temperature)

        _pressure = d.pop("pressure", UNSET)
        pressure: Union[Unset, ApiValuePressure]
        if isinstance(_pressure, Unset):
            pressure = UNSET
        else:
            pressure = ApiValuePressure.from_dict(_pressure)

        phases = []
        _phases = d.pop("phases", UNSET)
        for phases_item_data in _phases or []:
            phases_item = ApiOutputCalculationResultPhase.from_dict(phases_item_data)

            phases.append(phases_item)

        api_output_calculation_result_point = cls(
            temperature=temperature,
            pressure=pressure,
            phases=phases,
        )

        return api_output_calculation_result_point



from equia.models import CalculationComposition, FlashCalculationInput, FlashCalculationType


def test_flash_input_mapped():
    body = {
        "userId": "",
        "accessSecret": "",
        "temperature": 445,
        "pressure": 20,
        "components": [
            {"mass": 0.78},
            {"mass": 0.02},
            {"mass": 0.20}
        ],
        "flashType": 0,
        "fluidId": "9E9ABAD5-C6CA-427F-B5E7-15AB3F7CF076",
        "units": {
            "temperature": {
                "in": "Kelvin",
                "out": "Kelvin"
            },
            "pressure": {
                "in": "Bar",
                "out": "Bar"
            },
            "composition": {
                "in": "Massfraction",
                "out": "Massfraction"
            },
            "enthalpy": {
                "in": "kJ/Kg",
                "out": "kJ/Kg"
            },
            "entropy": {
                "in": "kJ/(Kg Kelvin)",
                "out": "kJ/(Kg Kelvin)"
            }
        }
    }
    input = FlashCalculationInput.from_dict(body)

    assert input.fluid_id == "9E9ABAD5-C6CA-427F-B5E7-15AB3F7CF076"
    assert input.temperature == 445
    assert input.pressure == 20
    assert input.flash_type == FlashCalculationType.PT
    assert len(input.components) == 3


def test_composition_mapped():
    body = {"mass": 0.78}
    input = CalculationComposition.from_dict(body)

    assert input.mass == 0.78



from enum import Enum


class PropertyReferencePoint(int, Enum):
    ORIGINAL = 0
    """0 - Original"""
    IDEAL_GAS = 1
    """1 - Ideal Gas"""
    STANDARD_STATE = 2
    """2 - Standard State"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiValueFloatingWithOutUnitsName")


@attr.s(auto_attribs=True)
class ApiValueFloatingWithOutUnitsName:
    """Holds composition value"""

    value: Union[Unset, float] = UNSET
    name: Union[Unset, None, str] = UNSET
    molar_mass: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        value = self.value
        name = self.name
        molar_mass = self.molar_mass

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if value is not UNSET:
            field_dict["value"] = value
        if name is not UNSET:
            field_dict["name"] = name
        if molar_mass is not UNSET:
            field_dict["molarMass"] = molar_mass

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        value = d.pop("value", UNSET)

        name = d.pop("name", UNSET)

        molar_mass = d.pop("molarMass", UNSET)

        api_value_floating_with_out_units_name = cls(
            value=value,
            name=name,
            molar_mass=molar_mass,
        )

        return api_value_floating_with_out_units_name



import pytest
from equia.models import CalculationComposition, FlashCalculationType, ProblemDetails, ApiCallResult 
from equia.equia_client import EquiaClient
from equia.demofluids.fluids import nHexane_Ethylene_HDPE7

@pytest.mark.asyncio
async def test_call_flash():
    client = EquiaClient(
      "https://localhost:5201", "760C278E-20F7-4E31-AD0E-D0CF564D1414", "##glD47#al!=(d+53ES3?qW") # "https://api.equia.com", "UserId", "AccessSecret")

    input = client.get_flash_input()
    input.temperature = 445
    input.pressure = 20
    input.components = [
        CalculationComposition(mass=0.78),
        CalculationComposition(mass=0.02),
        CalculationComposition(mass=0.20)
    ]
    input.flash_type = FlashCalculationType.PT

    input.fluid = nHexane_Ethylene_HDPE7()
    input.units = "C(In,Massfraction);C(Out,Massfraction);T(In,Kelvin);T(Out,Kelvin);P(In,Bar);P(Out,Bar);H(In,kJ/Kg);H(Out,kJ/Kg);S(In,kJ/(Kg Kelvin));S(Out,kJ/(Kg Kelvin));Cp(In,kJ/(Kg Kelvin));Cp(Out,kJ/(Kg Kelvin));Viscosity(In,centiPoise);Viscosity(Out,centiPoise);Surfacetension(In,N/m);Surfacetension(Out,N/m)"

    result: ProblemDetails = await client.call_flash_async(input)

    await client.cleanup()

    #assert result.status == 400
    assert result.api_status == ApiCallResult.SUCCESS
    assert len(result.point.phases) == 4



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_value_component_composition import ApiValueComponentComposition
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiValueCompositionArray")


@attr.s(auto_attribs=True)
class ApiValueCompositionArray:
    """Holds compositioninfo"""

    components: Union[Unset, None, List[ApiValueComponentComposition]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        components: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.components, Unset):
            if self.components is None:
                components = None
            else:
                components = []
                for components_item_data in self.components:
                    components_item = components_item_data.to_dict()

                    components.append(components_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if components is not UNSET:
            field_dict["components"] = components

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        components = []
        _components = d.pop("components", UNSET)
        for components_item_data in _components or []:
            components_item = ApiValueComponentComposition.from_dict(components_item_data)

            components.append(components_item)

        api_value_composition_array = cls(
            components=components,
        )

        return api_value_composition_array



from equia.models import ApiFluid, EosModel, CpModel, IsAlkane, PolymerType, ApiFluidStandardComponent,ApiFluidPolymerComponent,ApiFluidComponentBlock,ApiFluidPseudoComponent, ApiFluidKij

def nHexane_Ethylene_HDPE7() -> ApiFluid:
    fluid = ApiFluid()
    fluid.name = "n-Hexane + Ethylene + HDPE(7)"
    fluid.eos = EosModel.PCSAFT
    fluid.solvent_cp = CpModel.DIPPR
    fluid.polymer_cp = CpModel.POLYNOMIAL

    fluid.standards = [
      ApiFluidStandardComponent(name="n-Hexane", is_alkane=IsAlkane.YES, molar_mass=86.17536,         
        standard_acentric_factor = 0.301261,
        critical_pressure = 30.25,
        critical_temperature = 507.6,
        pc_saftdm = 0.03548,
        pc_saft_sigma_0 = 3.7983,
        pc_saft_epsilon = 236.77),
      ApiFluidStandardComponent(name="Ethylene", is_alkane=IsAlkane.YES, molar_mass=28.05316,         
        standard_acentric_factor = 0.087,
        critical_pressure = 50.41,
        critical_temperature = 282.34,
        pc_saftdm = 0.0567914,
        pc_saft_sigma_0 = 3.445,
        pc_saft_epsilon = 176.47),
      ]

    fluid.polymers = [
        ApiFluidPolymerComponent(short_name="HDPE", polymer_type=PolymerType.POLYMER,
          blocks=[
            ApiFluidComponentBlock(monomer_name="Ethylene", monomer_molar_mass=28.054, pc_saftdm = 0.0263, pc_saft_sigma_0 = 4.0217, pc_saft_epsilon = 252.0)
                                 ],
          pseudo_components=[
            ApiFluidPseudoComponent(name= "HDPE(17.3)", melting_temperature = 415.82, molar_mass = 17300,  massfraction = 0.00498),
            ApiFluidPseudoComponent(name= "HDPE(25.6)", melting_temperature = 416.38, molar_mass = 25600,  massfraction = 0.03067),
            ApiFluidPseudoComponent(name= "HDPE(36)",   melting_temperature = 416.72, molar_mass = 36000,  massfraction = 0.23902),
            ApiFluidPseudoComponent(name= "HDPE(50)",   melting_temperature = 416.95, molar_mass = 50000,  massfraction = 0.45515),
            ApiFluidPseudoComponent(name= "HDPE(69.2)", melting_temperature = 417.12, molar_mass = 69200,  massfraction = 0.23902),
            ApiFluidPseudoComponent(name= "HDPE(97.6)", melting_temperature = 417.24, molar_mass = 97600,  massfraction = 0.03067),
            ApiFluidPseudoComponent(name= "HDPE(144)",  melting_temperature = 417.34, molar_mass = 144000, massfraction = 0.0005)                                 ]                            
        )
      ]
    
    fluid.kij = [
      ApiFluidKij(index_i=0, index_j=1, kija=0.0001),
      ApiFluidKij(index_i=0, index_j=2, kija=0.0002),
      ApiFluidKij(index_i=1, index_j=2, kija=0.0003),
      ]

    return fluid



from enum import Enum


class PhaseType(int, Enum):
    RESULT = 0
    """0 - Result"""
    FEED = 1
    """1 - Feed"""
    SYSTEM = 2
    """2 - System"""
    ZERO_PHASE = 3
    """3 - ZeroPhase"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_output_unflashed_property_result_ideal import ApiOutputUnflashedPropertyResultIdeal
from ..models.api_output_unflashed_property_result_residual import ApiOutputUnflashedPropertyResultResidual
from ..models.api_value_pressure import ApiValuePressure
from ..models.api_value_temperature import ApiValueTemperature
from ..models.api_value_volume import ApiValueVolume
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputUnflashedPropertyResult")


@attr.s(auto_attribs=True)
class ApiOutputUnflashedPropertyResult:
    """Holds result for a point"""

    temperature: Union[Unset, ApiValueTemperature] = UNSET
    pressure: Union[Unset, ApiValuePressure] = UNSET
    volume: Union[Unset, ApiValueVolume] = UNSET
    residual: Union[Unset, ApiOutputUnflashedPropertyResultResidual] = UNSET
    ideal: Union[Unset, ApiOutputUnflashedPropertyResultIdeal] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        temperature: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.temperature, Unset):
            temperature = self.temperature.to_dict()

        pressure: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pressure, Unset):
            pressure = self.pressure.to_dict()

        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        residual: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.residual, Unset):
            residual = self.residual.to_dict()

        ideal: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ideal, Unset):
            ideal = self.ideal.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if pressure is not UNSET:
            field_dict["pressure"] = pressure
        if volume is not UNSET:
            field_dict["volume"] = volume
        if residual is not UNSET:
            field_dict["residual"] = residual
        if ideal is not UNSET:
            field_dict["ideal"] = ideal

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _temperature = d.pop("temperature", UNSET)
        temperature: Union[Unset, ApiValueTemperature]
        if isinstance(_temperature, Unset):
            temperature = UNSET
        else:
            temperature = ApiValueTemperature.from_dict(_temperature)

        _pressure = d.pop("pressure", UNSET)
        pressure: Union[Unset, ApiValuePressure]
        if isinstance(_pressure, Unset):
            pressure = UNSET
        else:
            pressure = ApiValuePressure.from_dict(_pressure)

        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, ApiValueVolume]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = ApiValueVolume.from_dict(_volume)

        _residual = d.pop("residual", UNSET)
        residual: Union[Unset, ApiOutputUnflashedPropertyResultResidual]
        if isinstance(_residual, Unset):
            residual = UNSET
        else:
            residual = ApiOutputUnflashedPropertyResultResidual.from_dict(_residual)

        _ideal = d.pop("ideal", UNSET)
        ideal: Union[Unset, ApiOutputUnflashedPropertyResultIdeal]
        if isinstance(_ideal, Unset):
            ideal = UNSET
        else:
            ideal = ApiOutputUnflashedPropertyResultIdeal.from_dict(_ideal)

        api_output_unflashed_property_result = cls(
            temperature=temperature,
            pressure=pressure,
            volume=volume,
            residual=residual,
            ideal=ideal,
        )

        return api_output_unflashed_property_result



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.api_fluid_kij import ApiFluidKij
from ..models.api_fluid_polymer_component import ApiFluidPolymerComponent
from ..models.api_fluid_standard_component import ApiFluidStandardComponent
from ..models.cp_model import CpModel
from ..models.eos_model import EosModel
from ..models.property_reference_point import PropertyReferencePoint
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiFluid")


@attr.s(auto_attribs=True)
class ApiFluid:
    """Information for a fluid"""

    fluid_id: Union[Unset, str] = UNSET
    creation_time: Union[Unset, datetime.datetime] = UNSET
    name: Union[Unset, None, str] = UNSET
    comment: Union[Unset, None, str] = UNSET
    eos: Union[Unset, EosModel] = UNSET
    property_reference_point: Union[Unset, PropertyReferencePoint] = UNSET
    solvent_cp: Union[Unset, CpModel] = UNSET
    polymer_cp: Union[Unset, CpModel] = UNSET
    standards: Union[Unset, None, List[ApiFluidStandardComponent]] = UNSET
    polymers: Union[Unset, None, List[ApiFluidPolymerComponent]] = UNSET
    kij: Union[Unset, None, List[ApiFluidKij]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        fluid_id = self.fluid_id
        creation_time: Union[Unset, str] = UNSET
        if not isinstance(self.creation_time, Unset):
            creation_time = self.creation_time.isoformat()

        name = self.name
        comment = self.comment
        eos: Union[Unset, str] = UNSET
        if not isinstance(self.eos, Unset):
            eos = self.eos.value

        property_reference_point: Union[Unset, str] = UNSET
        if not isinstance(self.property_reference_point, Unset):
            property_reference_point = self.property_reference_point.value

        solvent_cp: Union[Unset, str] = UNSET
        if not isinstance(self.solvent_cp, Unset):
            solvent_cp = self.solvent_cp.value

        polymer_cp: Union[Unset, str] = UNSET
        if not isinstance(self.polymer_cp, Unset):
            polymer_cp = self.polymer_cp.value

        standards: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.standards, Unset):
            if self.standards is None:
                standards = None
            else:
                standards = []
                for standards_item_data in self.standards:
                    standards_item = standards_item_data.to_dict()

                    standards.append(standards_item)

        polymers: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.polymers, Unset):
            if self.polymers is None:
                polymers = None
            else:
                polymers = []
                for polymers_item_data in self.polymers:
                    polymers_item = polymers_item_data.to_dict()

                    polymers.append(polymers_item)

        kij: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.kij, Unset):
            if self.kij is None:
                kij = None
            else:
                kij = []
                for kij_item_data in self.kij:
                    kij_item = kij_item_data.to_dict()

                    kij.append(kij_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if fluid_id is not UNSET:
            field_dict["fluidId"] = fluid_id
        if creation_time is not UNSET:
            field_dict["creationTime"] = creation_time
        if name is not UNSET:
            field_dict["name"] = name
        if comment is not UNSET:
            field_dict["comment"] = comment
        if eos is not UNSET:
            field_dict["eos"] = eos
        if property_reference_point is not UNSET:
            field_dict["propertyReferencePoint"] = property_reference_point
        if solvent_cp is not UNSET:
            field_dict["solventCp"] = solvent_cp
        if polymer_cp is not UNSET:
            field_dict["polymerCp"] = polymer_cp
        if standards is not UNSET:
            field_dict["standards"] = standards
        if polymers is not UNSET:
            field_dict["polymers"] = polymers
        if kij is not UNSET:
            field_dict["kij"] = kij

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        fluid_id = d.pop("fluidId", UNSET)

        _creation_time = d.pop("creationTime", UNSET)
        creation_time: Union[Unset, datetime.datetime]
        if isinstance(_creation_time, Unset):
            creation_time = UNSET
        else:
            creation_time = isoparse(_creation_time)

        name = d.pop("name", UNSET)

        comment = d.pop("comment", UNSET)

        _eos = d.pop("eos", UNSET)
        eos: Union[Unset, EosModel]
        if isinstance(_eos, Unset):
            eos = UNSET
        else:
            eos = EosModel(_eos)

        _property_reference_point = d.pop("propertyReferencePoint", UNSET)
        property_reference_point: Union[Unset, PropertyReferencePoint]
        if isinstance(_property_reference_point, Unset):
            property_reference_point = UNSET
        else:
            property_reference_point = PropertyReferencePoint(_property_reference_point)

        _solvent_cp = d.pop("solventCp", UNSET)
        solvent_cp: Union[Unset, CpModel]
        if isinstance(_solvent_cp, Unset):
            solvent_cp = UNSET
        else:
            solvent_cp = CpModel(_solvent_cp)

        _polymer_cp = d.pop("polymerCp", UNSET)
        polymer_cp: Union[Unset, CpModel]
        if isinstance(_polymer_cp, Unset):
            polymer_cp = UNSET
        else:
            polymer_cp = CpModel(_polymer_cp)

        standards = []
        _standards = d.pop("standards", UNSET)
        for standards_item_data in _standards or []:
            standards_item = ApiFluidStandardComponent.from_dict(standards_item_data)

            standards.append(standards_item)

        polymers = []
        _polymers = d.pop("polymers", UNSET)
        for polymers_item_data in _polymers or []:
            polymers_item = ApiFluidPolymerComponent.from_dict(polymers_item_data)

            polymers.append(polymers_item)

        kij = []
        _kij = d.pop("kij", UNSET)
        for kij_item_data in _kij or []:
            kij_item = ApiFluidKij.from_dict(kij_item_data)

            kij.append(kij_item)

        api_fluid = cls(
            fluid_id=fluid_id,
            creation_time=creation_time,
            name=name,
            comment=comment,
            eos=eos,
            property_reference_point=property_reference_point,
            solvent_cp=solvent_cp,
            polymer_cp=polymer_cp,
            standards=standards,
            polymers=polymers,
            kij=kij,
        )

        return api_fluid



import aiohttp
from typing import Any, Dict

from equia.models import CloudPointCalculationInput, CloudPointCalculationResult, CloudPointCalculationType, \
    FlashCalculationInput, FlashCalculationResult, FlashCalculationType, \
    FlashedPropertyCalculationInput, FlashedPropertyCalculationResult, PropertiesCalculationType, \
    PhasediagramFixedTemperaturePressureCalculationInput, PhasediagramFixedTemperaturePressureCalculationResult, \
    NewFluidInput, NewFluidResult, RequestFluidInput, RequestFluidResult, \
    SlePointCalculationInput, SlePointCalculationResult, SlePointCalculationType, \
    UnflashedPropertyCalculationInput, UnflashedPropertyCalculationResult, \
    ProblemDetails, Units, UnitsItem \



class EquiaClient:
    """Class for making the calling to Equia API easy"""

    def __init__(self, base_url, user_id, access_secret):
        self.__base_url = "{}/api/01/".format(base_url)
        self.__user_id = user_id
        self.__access_secret = access_secret
        self.__session = aiohttp.ClientSession(
            connector=aiohttp.TCPConnector(ssl=False))

    async def cleanup(self):
        await self.__session.close()

    def __append_body(self, body: Dict[str, Any]) -> Dict[str, Any]:
        """Method that appends user_id and access_secret to the body of the request"""
        user = {
            "userId": self.__user_id,
            "accessSecret": self.__access_secret,
        }
        return {**body, **user}

    async def __post_async(self, endpoint: str, json_body: Dict[str, Any], from_dict):
        """Prepare the URL and the body and makes the POST request to the API"""
        url = "{}{endpoint}".format(self.__base_url, endpoint=endpoint)
        json_body = self.__append_body(json_body)
        try:
            async with self.__session.post(url, json=json_body) as resp:
                response = await resp.json()
                if resp.status == 200:
                    return from_dict(response)
                else:
                    return ProblemDetails.from_dict(response)
        except aiohttp.ClientConnectorError as e:
            print('Connection Error', str(e))
            return ProblemDetails.from_dict(e)

    async def request_fluid_async(
        self,
        body: RequestFluidInput,
    ): return await self.__post_async("Fluid/RequestFluid", body.to_dict(), RequestFluidResult.from_dict)

    async def add_new_fluid_async(
        self,
        body: NewFluidInput,
    ): return await self.__post_async("Fluid/AddNewFluid", body.to_dict(), NewFluidResult.from_dict)

    async def call_flash_async(
        self,
        body: FlashCalculationInput,
    ):
        """Perform flash calculation"""
        return await self.__post_async("Calculation/Flash", body.to_dict(), FlashCalculationResult.from_dict)

    async def call_cloud_point_async(
        self,
        body: CloudPointCalculationInput,
    ):
        """Perform cloud point calculation"""
        return await self.__post_async("Calculation/CloudPoint", body.to_dict(), CloudPointCalculationResult.from_dict)

    async def call_flashed_properties_async(
        self,
        body: FlashedPropertyCalculationInput,
    ):
        """Perform flash property calculation"""
        return await self.__post_async("Calculation/FlashedProperties", body.to_dict(), FlashedPropertyCalculationResult.from_dict)

    async def call_unflashed_properties_async(
        self,
        body: UnflashedPropertyCalculationInput,
    ):
        """Perform un-flash property calculation"""
        return await self.__post_async("Calculation/UnflashedProperties", body.to_dict(), UnflashedPropertyCalculationResult.from_dict)

    async def call_sle_point_async(
        self,
        body: SlePointCalculationInput,
    ):
        """Perform SLE point calculation"""
        return await self.__post_async("Calculation/SlePoint", body.to_dict(), SlePointCalculationResult.from_dict)

    async def call_calculation_phasediagram_standard_async(
        self,
        body: PhasediagramFixedTemperaturePressureCalculationInput,
    ):
        """Perform Phasediagram standard calculation"""
        return await self.__post_async("Calculation/PhasediagramStandard", body.to_dict(), PhasediagramFixedTemperaturePressureCalculationResult.from_dict)

    def get_flash_input(self):
        """Returns flash argument filled with standard input"""
        return FlashCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units(), components=[], fluid_id="", flash_type=FlashCalculationType.PT)

    def get_cloud_point_input(self):
        """Returns cloud point argument filled with standard input"""
        return CloudPointCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units(), components=[], fluid_id="", point_type=CloudPointCalculationType.FIXED_TEMPERATURE)

    def get_flashed_property_Input(self):
        """Returns flashed properties argument filled with standard input"""
        return FlashedPropertyCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units(), components=[], fluid_id="", property_type=PropertiesCalculationType.PT)

    def get_unflashed_property_input(self):
        """Returns un-flashed properties argument filled with standard input"""
        return UnflashedPropertyCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units(), components=[], fluid_id="", calculation_type=PropertiesCalculationType.PT)

    def get_sle_point_input(self):
        """Returns SLE point argument filled with standard input"""
        return SlePointCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units(), components=[], fluid_id="", point_type=SlePointCalculationType.FIXED_PRESSURE)

    def get_phasediagam_standard_input(self):
        """Returns phase diagram standard argument filled with standard input"""
        return PhasediagramFixedTemperaturePressureCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units(), components=[], fluid_id="")

    def get_request_fluid_input(self):
        """Returns request fluid argument filled with standard input"""
        return RequestFluidInput(user_id=self.__user_id, access_secret=self.__access_secret)

    def get_new_fluid_input(self):
        """Returns new fluid argument filled with standard input"""
        return NewFluidInput(user_id=self.__user_id, access_secret=self.__access_secret)

    def __get_units(self):
        return Units(temperature=UnitsItem(in_="Kelvin", out="Kelvin"), pressure=UnitsItem(in_="Bar", out="Bar"), composition=UnitsItem(in_="Massfraction", out="Massfraction"), enthalpy=UnitsItem(in_="kJ/Kg", out="kJ/Kg"), entropy=UnitsItem(in_="kJ/(Kg Kelvin)", out="kJ/(Kg Kelvin)"))



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.calculation_composition import CalculationComposition
from ..models.properties_calculation_type import PropertiesCalculationType
from ..models.units import Units
from ..types import UNSET, Unset

T = TypeVar("T", bound="UnflashedPropertyCalculationInput")


@attr.s(auto_attribs=True)
class UnflashedPropertyCalculationInput:
    """Input to property calculation"""

    user_id: str
    access_secret: str
    components: List[CalculationComposition]
    fluid_id: str
    calculation_type: PropertiesCalculationType
    units: Union[Unset, Units] = UNSET
    temperature: Union[Unset, float] = UNSET
    pressure: Union[Unset, float] = UNSET
    volume: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        user_id = self.user_id
        access_secret = self.access_secret
        components = []
        for components_item_data in self.components:
            components_item = components_item_data.to_dict()

            components.append(components_item)

        fluid_id = self.fluid_id
        calculation_type = self.calculation_type.value

        units: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.units, Unset):
            units = self.units.to_dict()

        temperature = self.temperature
        pressure = self.pressure
        volume = self.volume

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "userId": user_id,
                "accessSecret": access_secret,
                "components": components,
                "fluidId": fluid_id,
                "calculationType": calculation_type,
            }
        )
        if units is not UNSET:
            field_dict["units"] = units
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if pressure is not UNSET:
            field_dict["pressure"] = pressure
        if volume is not UNSET:
            field_dict["volume"] = volume

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_id = d.pop("userId")

        access_secret = d.pop("accessSecret")

        components = []
        _components = d.pop("components")
        for components_item_data in _components:
            components_item = CalculationComposition.from_dict(components_item_data)

            components.append(components_item)

        fluid_id = d.pop("fluidId")

        calculation_type = PropertiesCalculationType(d.pop("calculationType"))

        _units = d.pop("units", UNSET)
        units: Union[Unset, Units]
        if isinstance(_units, Unset):
            units = UNSET
        else:
            units = Units.from_dict(_units)

        temperature = d.pop("temperature", UNSET)

        pressure = d.pop("pressure", UNSET)

        volume = d.pop("volume", UNSET)

        unflashed_property_calculation_input = cls(
            user_id=user_id,
            access_secret=access_secret,
            components=components,
            fluid_id=fluid_id,
            calculation_type=calculation_type,
            units=units,
            temperature=temperature,
            pressure=pressure,
            volume=volume,
        )

        return unflashed_property_calculation_input



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.calculation_composition import CalculationComposition
from ..models.flash_calculation_type import FlashCalculationType
from ..models.api_fluid import ApiFluid
from ..types import UNSET, Unset

T = TypeVar("T", bound="FlashCalculationInput")


@attr.s(auto_attribs=True)
class FlashCalculationInput:
    """Input for flash calculation"""

    user_id: str
    access_secret: str
    components: List[CalculationComposition]
    flash_type: FlashCalculationType
    units: str
    fluid_id: Union[Unset, str] = UNSET
    fluid: Union[Unset, ApiFluid] = UNSET
    temperature: Union[Unset, float] = UNSET
    pressure: Union[Unset, float] = UNSET
    enthalpy: Union[Unset, float] = UNSET
    entropy: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        user_id = self.user_id
        access_secret = self.access_secret
        components = []
        for components_item_data in self.components:
            components_item = components_item_data.to_dict()

            components.append(components_item)

        flash_type = self.flash_type.value
        units = self.units
        temperature = self.temperature
        pressure = self.pressure
        enthalpy = self.enthalpy
        entropy = self.entropy

        fluid_id: Union[Unset, str] = UNSET
        if not isinstance(self.fluid_id, Unset):
            fluid = self.fluid_id

        fluid: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fluid, Unset):
            fluid = self.fluid.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "userId": user_id,
                "accessSecret": access_secret,
                "components": components,
                "flashType": flash_type,
            }
        )
        if units is not UNSET:
            field_dict["units"] = units
        if fluid_id is not UNSET:
            field_dict["fluidId"] = fluid_id
        if fluid is not UNSET:
            field_dict["fluid"] = fluid
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if pressure is not UNSET:
            field_dict["pressure"] = pressure
        if enthalpy is not UNSET:
            field_dict["enthalpy"] = enthalpy
        if entropy is not UNSET:
            field_dict["entropy"] = entropy

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_id = d.pop("userId")
        access_secret = d.pop("accessSecret")
        flash_type = FlashCalculationType(d.pop("flashType"))
        units = d.pop("units", UNSET)

        components = []
        _components = d.pop("components")
        for components_item_data in _components:
            components_item = CalculationComposition.from_dict(
                components_item_data)

            components.append(components_item)

        _fluid_id = d.pop("fluidId", UNSET)
        fluid_id: Union[Unset, str]
        if isinstance(_fluid_id, Unset):
            fluid_id = UNSET
        else:
            fluid_id = _fluid_id

        _fluid = d.pop("fluid", UNSET)
        fluid: Union[Unset, ApiFluid]
        if isinstance(_fluid, Unset):
            fluid = UNSET
        else:
            fluid = ApiFluid.from_dict(_fluid)

        temperature = d.pop("temperature", UNSET)
        pressure = d.pop("pressure", UNSET)
        enthalpy = d.pop("enthalpy", UNSET)
        entropy = d.pop("entropy", UNSET)

        flash_calculation_input = cls(
            user_id=user_id,
            access_secret=access_secret,
            components=components,
            flash_type=flash_type,
            units=units,
            fluid_id=fluid_id,
            fluid=fluid,
            temperature=temperature,
            pressure=pressure,
            enthalpy=enthalpy,
            entropy=entropy,
        )

        return flash_calculation_input



from enum import Enum


class EosModel(int, Enum):
    PCSAFT = 0
    """0 - PC-SAFT"""
    CO_PCSAFT = 1
    """1 - coPC-SAFT"""
    PR = 2
    """2 - PR"""
    SRK = 3
    """3 - SRK"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_call_result import ApiCallResult
from ..models.api_output_unflashed_property_result import ApiOutputUnflashedPropertyResult
from ..models.api_profile_information import ApiProfileInformation
from ..models.exception_info import ExceptionInfo
from ..types import UNSET, Unset

T = TypeVar("T", bound="UnflashedPropertyCalculationResult")


@attr.s(auto_attribs=True)
class UnflashedPropertyCalculationResult:
    """Holds calculation result for a point"""

    api_status: Union[Unset, ApiCallResult] = UNSET
    calculation_id: Union[Unset, None, str] = UNSET
    exception_info: Union[Unset, ExceptionInfo] = UNSET
    profiling: Union[Unset, ApiProfileInformation] = UNSET
    point: Union[Unset, ApiOutputUnflashedPropertyResult] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        api_status: Union[Unset, str] = UNSET
        if not isinstance(self.api_status, Unset):
            api_status = self.api_status.value

        calculation_id = self.calculation_id
        exception_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.exception_info, Unset):
            exception_info = self.exception_info.to_dict()

        profiling: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profiling, Unset):
            profiling = self.profiling.to_dict()

        point: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.point, Unset):
            point = self.point.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if api_status is not UNSET:
            field_dict["apiStatus"] = api_status
        if calculation_id is not UNSET:
            field_dict["calculationId"] = calculation_id
        if exception_info is not UNSET:
            field_dict["exceptionInfo"] = exception_info
        if profiling is not UNSET:
            field_dict["profiling"] = profiling
        if point is not UNSET:
            field_dict["point"] = point

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _api_status = d.pop("apiStatus", UNSET)
        api_status: Union[Unset, ApiCallResult]
        if isinstance(_api_status, Unset):
            api_status = UNSET
        else:
            api_status = ApiCallResult(_api_status)

        calculation_id = d.pop("calculationId", UNSET)

        _exception_info = d.pop("exceptionInfo", UNSET)
        exception_info: Union[Unset, ExceptionInfo]
        if isinstance(_exception_info, Unset):
            exception_info = UNSET
        else:
            exception_info = ExceptionInfo.from_dict(_exception_info)

        _profiling = d.pop("profiling", UNSET)
        profiling: Union[Unset, ApiProfileInformation]
        if isinstance(_profiling, Unset):
            profiling = UNSET
        else:
            profiling = ApiProfileInformation.from_dict(_profiling)

        _point = d.pop("point", UNSET)
        point: Union[Unset, ApiOutputUnflashedPropertyResult]
        if isinstance(_point, Unset):
            point = UNSET
        else:
            point = ApiOutputUnflashedPropertyResult.from_dict(_point)

        unflashed_property_calculation_result = cls(
            api_status=api_status,
            calculation_id=calculation_id,
            exception_info=exception_info,
            profiling=profiling,
            point=point,
        )

        return unflashed_property_calculation_result



""" Contains all the data models used in inputs/outputs """

from equia.models.api_call_result import ApiCallResult
from equia.models.api_fluid import ApiFluid
from equia.models.api_fluid_component_block import ApiFluidComponentBlock
from equia.models.api_fluid_kij import ApiFluidKij
from equia.models.api_fluid_polymer_component import ApiFluidPolymerComponent
from equia.models.api_fluid_pseudo_component import ApiFluidPseudoComponent
from equia.models.api_fluid_standard_component import ApiFluidStandardComponent
from equia.models.api_output_calculation_result_phase import ApiOutputCalculationResultPhase
from equia.models.api_output_calculation_result_phase_composition import ApiOutputCalculationResultPhaseComposition
from equia.models.api_output_calculation_result_phase_polymer_moment import ApiOutputCalculationResultPhasePolymerMoment
from equia.models.api_output_calculation_result_phase_polymer_moments import ApiOutputCalculationResultPhasePolymerMoments
from equia.models.api_output_calculation_result_point import ApiOutputCalculationResultPoint
from equia.models.api_output_phasediagram import ApiOutputPhasediagram
from equia.models.api_output_phasediagram_point import ApiOutputPhasediagramPoint
from equia.models.api_output_unflashed_property_result import ApiOutputUnflashedPropertyResult
from equia.models.api_output_unflashed_property_result_ideal import ApiOutputUnflashedPropertyResultIdeal
from equia.models.api_output_unflashed_property_result_residual import ApiOutputUnflashedPropertyResultResidual
from equia.models.api_profile_information import ApiProfileInformation
from equia.models.api_profile_time_information import ApiProfileTimeInformation
from equia.models.api_value_floating_with_out_units import ApiValueFloatingWithOutUnits
from equia.models.api_value_floating_with_out_units_name import ApiValueFloatingWithOutUnitsName
from equia.models.api_value_floating_with_units import ApiValueFloatingWithUnits
from equia.models.api_value_component_composition import ApiValueComponentComposition
from equia.models.api_value_composition_array import ApiValueCompositionArray
from equia.models.api_value_compressibility import ApiValueCompressibility
from equia.models.api_value_density import ApiValueDensity
from equia.models.api_value_enthalpy import ApiValueEnthalpy
from equia.models.api_value_entropy import ApiValueEntropy
from equia.models.api_value_mole_percent import ApiValueMolePercent
from equia.models.api_value_pressure import ApiValuePressure
from equia.models.api_value_temperature import ApiValueTemperature
from equia.models.api_value_volume import ApiValueVolume
from equia.models.api_value_weight_percent import ApiValueWeightPercent
from equia.models.association_scheme import AssociationScheme
from equia.models.calculation_block_info import CalculationBlockInfo
from equia.models.calculation_composition import CalculationComposition
from equia.models.cloud_point_calculation_input import CloudPointCalculationInput
from equia.models.cloud_point_calculation_result import CloudPointCalculationResult
from equia.models.cloud_point_calculation_type import CloudPointCalculationType
from equia.models.component_type import ComponentType
from equia.models.cp_model import CpModel
from equia.models.distribution_model import DistributionModel
from equia.models.eos_model import EosModel
from equia.models.exception_info import ExceptionInfo
from equia.models.flash_calculation_input import FlashCalculationInput
from equia.models.flash_calculation_result import FlashCalculationResult
from equia.models.flash_calculation_type import FlashCalculationType
from equia.models.flashed_property_calculation_input import FlashedPropertyCalculationInput
from equia.models.flashed_property_calculation_result import FlashedPropertyCalculationResult
from equia.models.api_fluid_distribution_moment import ApiFluidDistributionMoment
from equia.models.is_alkane import IsAlkane
from equia.models.new_fluid_input import NewFluidInput
from equia.models.new_fluid_result import NewFluidResult
from equia.models.phasediagram_fixed_temperature_pressure_calculation_input import (
    PhasediagramFixedTemperaturePressureCalculationInput,
)
from equia.models.phasediagram_fixed_temperature_pressure_calculation_result import (
    PhasediagramFixedTemperaturePressureCalculationResult,
)
from equia.models.phase_type import PhaseType
from equia.models.polymer_type import PolymerType
from equia.models.problem_details import ProblemDetails
from equia.models.properties_calculation_type import PropertiesCalculationType
from equia.models.property_reference_point import PropertyReferencePoint
from equia.models.request_fluid_input import RequestFluidInput
from equia.models.request_fluid_result import RequestFluidResult
from equia.models.sle_point_calculation_input import SlePointCalculationInput
from equia.models.sle_point_calculation_result import SlePointCalculationResult
from equia.models.sle_point_calculation_type import SlePointCalculationType
from equia.models.unflashed_property_calculation_input import UnflashedPropertyCalculationInput
from equia.models.unflashed_property_calculation_result import UnflashedPropertyCalculationResult
from equia.models.units import Units
from equia.models.units_item import UnitsItem



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiValueWeightPercent")


@attr.s(auto_attribs=True)
class ApiValueWeightPercent:
    """Weight fraction information"""

    value: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        value = self.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        value = d.pop("value", UNSET)

        api_value_weight_percent = cls(
            value=value,
        )

        return api_value_weight_percent



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.units_item import UnitsItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="Units")


@attr.s(auto_attribs=True)
class Units:
    """Holds all unit information"""

    temperature: Union[Unset, UnitsItem] = UNSET
    pressure: Union[Unset, UnitsItem] = UNSET
    composition: Union[Unset, UnitsItem] = UNSET
    enthalpy: Union[Unset, UnitsItem] = UNSET
    entropy: Union[Unset, UnitsItem] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        temperature: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.temperature, Unset):
            temperature = self.temperature.to_dict()

        pressure: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pressure, Unset):
            pressure = self.pressure.to_dict()

        composition: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.composition, Unset):
            composition = self.composition.to_dict()

        enthalpy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.enthalpy, Unset):
            enthalpy = self.enthalpy.to_dict()

        entropy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.entropy, Unset):
            entropy = self.entropy.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if pressure is not UNSET:
            field_dict["pressure"] = pressure
        if composition is not UNSET:
            field_dict["composition"] = composition
        if enthalpy is not UNSET:
            field_dict["enthalpy"] = enthalpy
        if entropy is not UNSET:
            field_dict["entropy"] = entropy

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _temperature = d.pop("temperature", UNSET)
        temperature: Union[Unset, UnitsItem]
        if isinstance(_temperature, Unset):
            temperature = UNSET
        else:
            temperature = UnitsItem.from_dict(_temperature)

        _pressure = d.pop("pressure", UNSET)
        pressure: Union[Unset, UnitsItem]
        if isinstance(_pressure, Unset):
            pressure = UNSET
        else:
            pressure = UnitsItem.from_dict(_pressure)

        _composition = d.pop("composition", UNSET)
        composition: Union[Unset, UnitsItem]
        if isinstance(_composition, Unset):
            composition = UNSET
        else:
            composition = UnitsItem.from_dict(_composition)

        _enthalpy = d.pop("enthalpy", UNSET)
        enthalpy: Union[Unset, UnitsItem]
        if isinstance(_enthalpy, Unset):
            enthalpy = UNSET
        else:
            enthalpy = UnitsItem.from_dict(_enthalpy)

        _entropy = d.pop("entropy", UNSET)
        entropy: Union[Unset, UnitsItem]
        if isinstance(_entropy, Unset):
            entropy = UNSET
        else:
            entropy = UnitsItem.from_dict(_entropy)

        units = cls(
            temperature=temperature,
            pressure=pressure,
            composition=composition,
            enthalpy=enthalpy,
            entropy=entropy,
        )

        return units



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_call_result import ApiCallResult
from ..models.api_fluid import ApiFluid
from ..models.exception_info import ExceptionInfo
from ..types import UNSET, Unset

T = TypeVar("T", bound="RequestFluidResult")


@attr.s(auto_attribs=True)
class RequestFluidResult:
    """Holds result for requesting information for a fluid"""

    api_status: Union[Unset, ApiCallResult] = UNSET
    fluid: Union[Unset, ApiFluid] = UNSET
    exception_info: Union[Unset, ExceptionInfo] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        api_status: Union[Unset, str] = UNSET
        if not isinstance(self.api_status, Unset):
            api_status = self.api_status.value

        fluid: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fluid, Unset):
            fluid = self.fluid.to_dict()

        exception_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.exception_info, Unset):
            exception_info = self.exception_info.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if api_status is not UNSET:
            field_dict["apiStatus"] = api_status
        if fluid is not UNSET:
            field_dict["fluid"] = fluid
        if exception_info is not UNSET:
            field_dict["exceptionInfo"] = exception_info

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _api_status = d.pop("apiStatus", UNSET)
        api_status: Union[Unset, ApiCallResult]
        if isinstance(_api_status, Unset):
            api_status = UNSET
        else:
            api_status = ApiCallResult(_api_status)

        _fluid = d.pop("fluid", UNSET)
        fluid: Union[Unset, ApiFluid]
        if isinstance(_fluid, Unset):
            fluid = UNSET
        else:
            fluid = ApiFluid.from_dict(_fluid)

        _exception_info = d.pop("exceptionInfo", UNSET)
        exception_info: Union[Unset, ExceptionInfo]
        if isinstance(_exception_info, Unset):
            exception_info = UNSET
        else:
            exception_info = ExceptionInfo.from_dict(_exception_info)

        request_fluid_result = cls(
            api_status=api_status,
            fluid=fluid,
            exception_info=exception_info,
        )

        return request_fluid_result



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_fluid import ApiFluid
from ..types import UNSET, Unset

T = TypeVar("T", bound="NewFluidInput")


@attr.s(auto_attribs=True)
class NewFluidInput:
    """Input for added new fluid to database"""

    user_id: str
    access_secret: str
    fluid: Union[Unset, ApiFluid] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        user_id = self.user_id
        access_secret = self.access_secret
        fluid: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fluid, Unset):
            fluid = self.fluid.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "userId": user_id,
                "accessSecret": access_secret,
            }
        )
        if fluid is not UNSET:
            field_dict["fluid"] = fluid

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_id = d.pop("userId")

        access_secret = d.pop("accessSecret")

        _fluid = d.pop("fluid", UNSET)
        fluid: Union[Unset, ApiFluid]
        if isinstance(_fluid, Unset):
            fluid = UNSET
        else:
            fluid = ApiFluid.from_dict(_fluid)

        new_fluid_input = cls(
            user_id=user_id,
            access_secret=access_secret,
            fluid=fluid,
        )

        return new_fluid_input
